@@ -1,5 +1,6 @@
 import os
-import pkgutil
+import pkg_resources
+
 
 def Flider():
     try:
@@ -15,6 +16,7 @@ def Flider():
     file_names = ['index.html', 'mysqlcontroller.py', '__init__.py', 'style.css', 'scripts.js', 'server.py']
     read_names = ['index.txt', 'mysqlcontroller.txt', 'init.txt', 'style.txt', 'scripts.txt', 'server.txt']
     for i in range(len(save_paths)):
+        print(__file__)
         try:
             completeName = os.path.join(save_paths[i], file_names[i])
             read_file = open(read_names[i], 'r')
